/*$Id: d_coment.cc,v 17.4 2000/03/19 04:20:02 al Exp $ -*- C++ -*-
 * processing for COMMENT netlist item (pseudo-device)
 * Old C style hack:
 * uses the space in a "card" struct, overwrites the leftover
 * Maybe the class hierarchy needs another level
 */
#include "ap.h"
#include "d_coment.h"
/*--------------------------------------------------------------------------*/
//	void	DEV_COMMENT::parse(CS& cmd);
//	void	DEV_COMMENT::print(int,int)const;
/*--------------------------------------------------------------------------*/
void DEV_COMMENT::parse(CS& cmd)
{
  _s = cmd.fullstring();
}
/*--------------------------------------------------------------------------*/
void DEV_COMMENT::print(OMSTREAM& where, int)const
{
  if (_s[0] != '*'  ||  _s[1] != '+'){
    where << _s << '\n';
  }
  // Suppress printing of comment lines starting with "*+".
  // These are generated as a way to display calculated values.
}
/*--------------------------------------------------------------------------*/
/*--------------------------------------------------------------------------*/
